@@ -7,5 +7,5 @@ pub(crate) fn to_ident(s: &str) -> Ident {
 
 /// Returns an ident with a suffix.
 pub(crate) fn suffix_ident(ident: &Ident, suffix: &str) -> Ident {
-    to_ident(&format!("{}{}", ident.to_string(), suffix))
+    to_ident(&format!("{}{}", ident, suffix))
 }
